@@ -42,7 +42,8 @@ $defaultImage = \Blue2\Scruffy\Site::getDefaultImage();
 $features = get_field('attributes');
 $galleryImages = $product->get_gallery_image_ids();
 $meta = get_post_meta(get_the_id());
-
+$terms = get_the_terms(get_the_id(), 'product_cat');
+$bookingSettings = get_post_meta(get_the_id(),'woocommerce_booking_settings',true);
 ?>
 <div id="product-<?php the_ID(); ?>" <?php wc_product_class( '', $product ); ?>>
     <div class="custom-single-product">
@@ -66,8 +67,10 @@ $meta = get_post_meta(get_the_id());
                                     <h1 class="fw-500"><?php the_title(); ?></h1>
                                     <div class="price">
                                         <?= get_woocommerce_currency_symbol() . number_format($product->get_price(), 2, '.', ''); ?>
-                                        <?php if (array_key_exists('_wc_booking_duration_unit', $meta)) { ?>
-                                            <span class="frequency">/ <?= $meta['_wc_booking_duration_unit'][0]; ?></span>
+                                        <?php if($bookingSettings !== "") { ?>
+                                            <span class="frequency">/ <?= $bookingSettings['bkap_duration_settings']['duration'] . " " . $bookingSettings['bkap_duration_settings']['duration_type']; ?></span>
+                                        <?php } elseif(!has_term('publications', 'product_cat')) { ?>
+                                            <span class="frequency">/ sqft</span>
                                         <?php } ?>
                                     </div>
                                 </div>
@@ -85,7 +88,19 @@ $meta = get_post_meta(get_the_id());
                                     <?php the_content(); ?>
 
                                     <div class="custom-buttons">
-                                        <a href="/enquiry/" class="enquire-button fw-700 u-case">Enquire Now</a>
+                                        <?php 
+                                        if (get_field('show_enquire_button') ) {
+                                        ?>
+                                            <a href="/enquiry/" class="enquire-button fw-700 u-case">Enquire Now</a>
+                                        <?php
+                                            }
+                                        ?>
+                                        <?php $libraryTerm = get_term_by('slug', 'shop', 'product_cat');
+                                        if($terms[0]->parent == $libraryTerm->term_id){
+                                            $add_to_cart = do_shortcode('[add_to_cart_url id="'. get_the_id() .'"]'); ?>
+                                            <a href="<?= $add_to_cart; ?>" class="u-case fw-700">Buy now</a>
+                                        <?php } ?>
+
                                         <?php if($galleryImages) { ?>
                                             <a href="#gallery" class="gallery-button fw-700 u-case">Gallery</a>
                                         <?php } ?>
@@ -119,7 +134,14 @@ $meta = get_post_meta(get_the_id());
             </section>
         <?php } ?>
 
-        <?php if(has_term('booking', 'product_type', get_the_id())) { ?>
+        <?php if($bookingSettings !== "") { 
+            ob_start();
+            do_action( 'woocommerce_single_product_summary' );
+            $content = ob_get_contents();
+            ob_end_clean();
+            $obContent = trim($Content);
+            if (!empty($obContent)) {
+        ?>
             <section class="booking-section">
                 <div class="contain">
                     <h2 class="fw-500 text-center">Booking</h2>
@@ -138,14 +160,15 @@ $meta = get_post_meta(get_the_id());
                              * @hooked woocommerce_template_single_sharing - 50
                              * @hooked WC_Structured_Data::generate_product_data() - 60
                              */
-                            do_action( 'woocommerce_single_product_summary' );
+                            echo $content;
                             ?>
                         </div>
                     </div>
                 </div>
             </section>
-        <?php } ?>
-
+        <?php 
+            }
+        } ?>
 
         <?php
         if($galleryImages) { ?>
